diff --git a/ChangeLog b/ChangeLog
--- a/ChangeLog
+++ b/ChangeLog
@@ -22,6 +22,10 @@
 
 	* configure.ac: Add check for mp_set_memory_functions.
 
+2013-03-24  Jeff Sparkes  <jsparkes@gmail.com>
+
+	* configure.ac: Check for XkbKeycodeToKeysym.
+
 2013-03-12  Jerry James  <james@xemacs.org>
 
 	* config.guess: Update to latest upstream version.
diff --git a/configure.ac b/configure.ac
--- a/configure.ac
+++ b/configure.ac
@@ -3157,6 +3157,7 @@
   fi
 
   AC_CHECK_FUNCS(XConvertCase XtRegisterDrawable)
+  AC_CHECK_FUNCS(XkbKeycodeToKeysym)
 
   AC_CHECK_HEADERS(X11/Xlocale.h X11/Xfuncproto.h)
 
diff --git a/src/ChangeLog b/src/ChangeLog
--- a/src/ChangeLog
+++ b/src/ChangeLog
@@ -145,6 +145,16 @@
 	HAVE_FSEEKO is the name of the C preprocessor symbol.  Do not
 	confuse the two.
 
+2013-03-24  Jeff Sparkes  <jsparkes@gmail.com>
+
+	* event-Xt.c: Include <X11/XKBlib.h> for XkbKeycodeToKeysym.
+
+	* config.h.in: Add HAVE_XKBKEYCODETOKEYSYM.
+
+	* event-Xt.c (x_reset_modifier_mapping): Use XkbKeycodeToKeysym
+	when available to avoid deprecation warning.  Remove unused variable
+	warned_about_duplicate_modifiers.
+
 2013-03-11  Vin Shelton  <acs@xemacs.org>
 
 	* config.h.in: Move large file support outside WIN32_NO_CONFIGURE block.
diff --git a/src/config.h.in b/src/config.h.in
--- a/src/config.h.in
+++ b/src/config.h.in
@@ -248,6 +248,7 @@
 
 #undef HAVE_XCONVERTCASE
 #undef HAVE_XTREGISTERDRAWABLE
+#undef HAVE_XKBKEYCODETOKEYSYM
 
 #undef HAVE_BALLOON_HELP
 
diff --git a/src/event-Xt.c b/src/event-Xt.c
--- a/src/event-Xt.c
+++ b/src/event-Xt.c
@@ -61,6 +61,7 @@
 				   a core widget directly.  We could
 				   use XtGetValues(), but ... */
 #include <X11/ShellP.h>
+#include <X11/XKBlib.h>
 
 #if defined (HAVE_XIM) && defined (XIM_MOTIF)
 #include "xmotif.h"
@@ -307,7 +308,6 @@
   int modifier_index, modifier_key, column, mkpm;
   int warned_about_overlapping_modifiers = 0;
   int warned_about_predefined_modifiers  = 0;
-  int warned_about_duplicate_modifiers   = 0;
   int meta_bit  = 0;
   int hyper_bit = 0;
   int super_bit = 0;
@@ -357,8 +357,7 @@
     warn_when_safe (Qkey_mapping, Qwarning,				\
  "XEmacs:  %s (0x%x) generates both %s and %s, which is nonsensical.",	\
 		    name, code, index_to_name (old),			\
-		    index_to_name (modifier_index)),			\
-    warned_about_duplicate_modifiers = 1;				\
+		    index_to_name (modifier_index));			\
   if (modifier_index == ShiftMapIndex) modbarf (name,"ModShift");	\
   else if (modifier_index == LockMapIndex) modbarf (name,"ModLock");	\
   else if (modifier_index == ControlMapIndex) modbarf (name,"ModControl"); \
@@ -382,7 +381,11 @@
       for (column = 0; column < 4; column += 2) {
 	KeyCode code = xd->x_modifier_keymap->modifiermap[modifier_index * mkpm
 							  + modifier_key];
+#ifdef HAVE_XKBKEYCODETOKEYSYM
+	KeySym sym = (code ? XkbKeycodeToKeysym (display, code, column, 0) : 0);
+#else
 	KeySym sym = (code ? XKeycodeToKeysym (display, code, column) : 0);
+#endif
 	if (sym == last_sym) continue;
 	last_sym = sym;
 	switch (sym) {
@@ -474,8 +477,6 @@
 "	assigning the key a different modifier bit.  You must also make that\n"
 "	key generate an appropriate keysym (Control_L, Meta_L, etc).");
 
-  /* No need to say anything more for warned_about_duplicate_modifiers. */
-
   if (warned_about_overlapping_modifiers || warned_about_predefined_modifiers)
     warn_when_safe (Qkey_mapping, Qwarning, "\n"
 "	The meanings of the modifier bits Mod1 through Mod5 are determined\n"
